@@ -1,7 +1,7 @@
 sub Mojo::Webqq::Client::_relink{
     my $self = shift;
     $self->login_state('relink');
-    $self->info("正在进行重新连接...");
+    $self->info("正在进行重新连接(2)...");
     my $api_url = 'http://d.web2.qq.com/channel/login2';
     my $headers = {Referer=>'http://d.web2.qq.com/proxy.html?v=20130916001&callback=1&id=2',json=>1};
     my %r = (
@@ -40,7 +40,7 @@ sub Mojo::Webqq::Client::_relink{
         $self->save_cookie();
         $self->_cookie_proxy();
         $self->login_state('success');
-        $self->info("重新连接成功");
+        $self->info("重新连接(2)成功");
         return 1;
     }
     else{
